# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from common.task.v1alpha import task_pb2 as common_dot_task_dot_v1alpha_dot_task__pb2
from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from model.model.v1alpha import model_definition_pb2 as model_dot_model_dot_v1alpha_dot_model__definition__pb2
from model.model.v1alpha import task_classification_pb2 as model_dot_model_dot_v1alpha_dot_task__classification__pb2
from model.model.v1alpha import task_detection_pb2 as model_dot_model_dot_v1alpha_dot_task__detection__pb2
from model.model.v1alpha import task_image_to_image_pb2 as model_dot_model_dot_v1alpha_dot_task__image__to__image__pb2
from model.model.v1alpha import task_instance_segmentation_pb2 as model_dot_model_dot_v1alpha_dot_task__instance__segmentation__pb2
from model.model.v1alpha import task_keypoint_pb2 as model_dot_model_dot_v1alpha_dot_task__keypoint__pb2
from model.model.v1alpha import task_ocr_pb2 as model_dot_model_dot_v1alpha_dot_task__ocr__pb2
from model.model.v1alpha import task_semantic_segmentation_pb2 as model_dot_model_dot_v1alpha_dot_task__semantic__segmentation__pb2
from model.model.v1alpha import task_text_generation_pb2 as model_dot_model_dot_v1alpha_dot_task__text__generation__pb2
from model.model.v1alpha import task_text_generation_chat_pb2 as model_dot_model_dot_v1alpha_dot_task__text__generation__chat__pb2
from model.model.v1alpha import task_text_to_image_pb2 as model_dot_model_dot_v1alpha_dot_task__text__to__image__pb2
from model.model.v1alpha import task_unspecified_pb2 as model_dot_model_dot_v1alpha_dot_task__unspecified__pb2
from model.model.v1alpha import task_visual_question_answering_pb2 as model_dot_model_dot_v1alpha_dot_task__visual__question__answering__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmodel/model/v1alpha/model.proto\x12\x13model.model.v1alpha\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1e\x63ommon/task/v1alpha/task.proto\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a#google/longrunning/operations.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a*model/model/v1alpha/model_definition.proto\x1a-model/model/v1alpha/task_classification.proto\x1a(model/model/v1alpha/task_detection.proto\x1a-model/model/v1alpha/task_image_to_image.proto\x1a\x34model/model/v1alpha/task_instance_segmentation.proto\x1a\'model/model/v1alpha/task_keypoint.proto\x1a\"model/model/v1alpha/task_ocr.proto\x1a\x34model/model/v1alpha/task_semantic_segmentation.proto\x1a.model/model/v1alpha/task_text_generation.proto\x1a\x33model/model/v1alpha/task_text_generation_chat.proto\x1a,model/model/v1alpha/task_text_to_image.proto\x1a*model/model/v1alpha/task_unspecified.proto\x1a\x38model/model/v1alpha/task_visual_question_answering.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x96\x01\n\x0fLivenessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"v\n\x10LivenessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\x97\x01\n\x10ReadinessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"w\n\x11ReadinessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\xb6\x08\n\x05Model\x12+\n\x04name\x18\x01 \x01(\tB\x17\x92\x41\x10\xca>\r\xfa\x02\nmodel_name\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12+\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x0b\x64\x65scription\x88\x01\x01\x12T\n\x10model_definition\x18\x05 \x01(\tB)\xe2\x41\x01\x05\xfa\x41\"\n api.instill.tech/ModelDefinitionR\x0fmodelDefinition\x12\x43\n\rconfiguration\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x05R\rconfiguration\x12\x33\n\x04task\x18\x07 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x04\xe2\x41\x01\x03R\x04task\x12<\n\x05state\x18\x08 \x01(\x0e\x32 .model.model.v1alpha.Model.StateB\x04\xe2\x41\x01\x03R\x05state\x12K\n\nvisibility\x18\t \x01(\x0e\x32%.model.model.v1alpha.Model.VisibilityB\x04\xe2\x41\x01\x03R\nvisibility\x12\x41\n\x0b\x63reate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\x41\n\x0b\x64\x65lete_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ndeleteTime\x12#\n\nowner_name\x18\x0f \x01(\tB\x04\xe2\x41\x01\x03R\townerName\x12\x39\n\x05owner\x18\x11 \x01(\x0b\x32\x17.core.mgmt.v1beta.OwnerB\x05\xe2\x41\x02\x01\x03H\x01R\x05owner\x88\x01\x01\"W\n\nVisibility\x12\x1a\n\x16VISIBILITY_UNSPECIFIED\x10\x00\x12\x16\n\x12VISIBILITY_PRIVATE\x10\x01\x12\x15\n\x11VISIBILITY_PUBLIC\x10\x02\"T\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_OFFLINE\x10\x01\x12\x10\n\x0cSTATE_ONLINE\x10\x02\x12\x0f\n\x0bSTATE_ERROR\x10\x03:R\xea\x41O\n\x16\x61pi.instill.tech/Model\x12!users/{user.id}/models/{model.id}\x12\x12models/{model.uid}B\x0e\n\x0c_descriptionB\x08\n\x06_ownerJ\x04\x08\x10\x10\x11\"\xe6\x01\n\tModelCard\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x18\n\x04size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x04size\x12\x18\n\x04type\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x04type\x12\x1e\n\x07\x63ontent\x18\x04 \x01(\x0c\x42\x04\xe2\x41\x01\x03R\x07\x63ontent\x12 \n\x08\x65ncoding\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x08\x65ncoding:I\xea\x41\x46\n\x1a\x61pi.instill.tech/ModelCard\x12(users/{user.id}/models/{model.id}/readme\"\x84\x02\n\x11ListModelsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x38\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12,\n\x0cshow_deleted\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x03R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deleted\"\x8f\x01\n\x12ListModelsResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelR\x06models\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"{\n\x12LookUpModelRequest\x12\"\n\tpermalink\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\tpermalink\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"G\n\x13LookUpModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\x95\x01\n\x16\x43reateUserModelRequest\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\x12I\n\x06parent\x18\x02 \x01(\tB1\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\"\\\n\x17\x43reateUserModelResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xcb\x01\n&CreateUserModelBinaryFileUploadRequest\x12\x36\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x04\xe2\x41\x01\x02R\x05model\x12\x1e\n\x07\x63ontent\x18\x02 \x01(\x0c\x42\x04\xe2\x41\x01\x02R\x07\x63ontent\x12I\n\x06parent\x18\x03 \x01(\tB1\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\"l\n\'CreateUserModelBinaryFileUploadResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xd3\x02\n\x15ListUserModelsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x38\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12I\n\x06parent\x18\x04 \x01(\tB1\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\x12,\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x03R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deleted\"\x93\x01\n\x16ListUserModelsResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelR\x06models\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xa5\x01\n\x13GetUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"H\n\x14GetUserModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\x93\x01\n\x16UpdateUserModelRequest\x12\x36\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x04\xe2\x41\x01\x02R\x05model\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"K\n\x17UpdateUserModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"e\n\x16\x44\x65leteUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"\x19\n\x17\x44\x65leteUserModelResponse\"\x8d\x01\n\x16RenameUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12&\n\x0cnew_model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\nnewModelId\"K\n\x17RenameUserModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"f\n\x17PublishUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"L\n\x18PublishUserModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"h\n\x19UnpublishUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"N\n\x1aUnpublishUserModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"e\n\x16\x44\x65ployUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"4\n\x17\x44\x65ployUserModelResponse\x12\x19\n\x08model_id\x18\x01 \x01(\tR\x07modelId\"g\n\x18UndeployUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"6\n\x19UndeployUserModelResponse\x12\x19\n\x08model_id\x18\x01 \x01(\tR\x07modelId\"o\n\x17GetUserModelCardRequest\x12T\n\x04name\x18\x01 \x01(\tB@\x92\x41\x1a\xca>\x17\xfa\x02\x14user_model_card_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ModelCardR\x04name\"R\n\x18GetUserModelCardResponse\x12\x36\n\x06readme\x18\x01 \x01(\x0b\x32\x1e.model.model.v1alpha.ModelCardR\x06readme\"d\n\x15WatchUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"l\n\x16WatchUserModelResponse\x12\x36\n\x05state\x18\x01 \x01(\x0e\x32 .model.model.v1alpha.Model.StateR\x05state\x12\x1a\n\x08progress\x18\x02 \x01(\x05R\x08progress\"\x80\x08\n\tTaskInput\x12R\n\x0e\x63lassification\x18\x01 \x01(\x0b\x32(.model.model.v1alpha.ClassificationInputH\x00R\x0e\x63lassification\x12\x43\n\tdetection\x18\x02 \x01(\x0b\x32#.model.model.v1alpha.DetectionInputH\x00R\tdetection\x12@\n\x08keypoint\x18\x03 \x01(\x0b\x32\".model.model.v1alpha.KeypointInputH\x00R\x08keypoint\x12\x31\n\x03ocr\x18\x04 \x01(\x0b\x32\x1d.model.model.v1alpha.OcrInputH\x00R\x03ocr\x12\x65\n\x15instance_segmentation\x18\x05 \x01(\x0b\x32..model.model.v1alpha.InstanceSegmentationInputH\x00R\x14instanceSegmentation\x12\x65\n\x15semantic_segmentation\x18\x06 \x01(\x0b\x32..model.model.v1alpha.SemanticSegmentationInputH\x00R\x14semanticSegmentation\x12K\n\rtext_to_image\x18\x07 \x01(\x0b\x32%.model.model.v1alpha.TextToImageInputH\x00R\x0btextToImage\x12N\n\x0eimage_to_image\x18\x08 \x01(\x0b\x32&.model.model.v1alpha.ImageToImageInputH\x00R\x0cimageToImage\x12S\n\x0ftext_generation\x18\t \x01(\x0b\x32(.model.model.v1alpha.TextGenerationInputH\x00R\x0etextGeneration\x12`\n\x14text_generation_chat\x18\n \x01(\x0b\x32,.model.model.v1alpha.TextGenerationChatInputH\x00R\x12textGenerationChat\x12o\n\x19visual_question_answering\x18\x0b \x01(\x0b\x32\x31.model.model.v1alpha.VisualQuestionAnsweringInputH\x00R\x17visualQuestionAnswering\x12I\n\x0bunspecified\x18\x0c \x01(\x0b\x32%.model.model.v1alpha.UnspecifiedInputH\x00R\x0bunspecifiedB\x07\n\x05input\"\xaa\x08\n\x0fTaskInputStream\x12X\n\x0e\x63lassification\x18\x01 \x01(\x0b\x32..model.model.v1alpha.ClassificationInputStreamH\x00R\x0e\x63lassification\x12I\n\tdetection\x18\x02 \x01(\x0b\x32).model.model.v1alpha.DetectionInputStreamH\x00R\tdetection\x12\x46\n\x08keypoint\x18\x03 \x01(\x0b\x32(.model.model.v1alpha.KeypointInputStreamH\x00R\x08keypoint\x12\x37\n\x03ocr\x18\x04 \x01(\x0b\x32#.model.model.v1alpha.OcrInputStreamH\x00R\x03ocr\x12k\n\x15instance_segmentation\x18\x05 \x01(\x0b\x32\x34.model.model.v1alpha.InstanceSegmentationInputStreamH\x00R\x14instanceSegmentation\x12k\n\x15semantic_segmentation\x18\x06 \x01(\x0b\x32\x34.model.model.v1alpha.SemanticSegmentationInputStreamH\x00R\x14semanticSegmentation\x12K\n\rtext_to_image\x18\x07 \x01(\x0b\x32%.model.model.v1alpha.TextToImageInputH\x00R\x0btextToImage\x12N\n\x0eimage_to_image\x18\x08 \x01(\x0b\x32&.model.model.v1alpha.ImageToImageInputH\x00R\x0cimageToImage\x12S\n\x0ftext_generation\x18\t \x01(\x0b\x32(.model.model.v1alpha.TextGenerationInputH\x00R\x0etextGeneration\x12`\n\x14text_generation_chat\x18\n \x01(\x0b\x32,.model.model.v1alpha.TextGenerationChatInputH\x00R\x12textGenerationChat\x12o\n\x19visual_question_answering\x18\x0b \x01(\x0b\x32\x31.model.model.v1alpha.VisualQuestionAnsweringInputH\x00R\x17visualQuestionAnswering\x12I\n\x0bunspecified\x18\x0c \x01(\x0b\x32%.model.model.v1alpha.UnspecifiedInputH\x00R\x0bunspecifiedB\x07\n\x05input\"\xd6\x08\n\nTaskOutput\x12Y\n\x0e\x63lassification\x18\x01 \x01(\x0b\x32).model.model.v1alpha.ClassificationOutputB\x04\xe2\x41\x01\x03H\x00R\x0e\x63lassification\x12J\n\tdetection\x18\x02 \x01(\x0b\x32$.model.model.v1alpha.DetectionOutputB\x04\xe2\x41\x01\x03H\x00R\tdetection\x12G\n\x08keypoint\x18\x03 \x01(\x0b\x32#.model.model.v1alpha.KeypointOutputB\x04\xe2\x41\x01\x03H\x00R\x08keypoint\x12\x38\n\x03ocr\x18\x04 \x01(\x0b\x32\x1e.model.model.v1alpha.OcrOutputB\x04\xe2\x41\x01\x03H\x00R\x03ocr\x12l\n\x15instance_segmentation\x18\x05 \x01(\x0b\x32/.model.model.v1alpha.InstanceSegmentationOutputB\x04\xe2\x41\x01\x03H\x00R\x14instanceSegmentation\x12l\n\x15semantic_segmentation\x18\x06 \x01(\x0b\x32/.model.model.v1alpha.SemanticSegmentationOutputB\x04\xe2\x41\x01\x03H\x00R\x14semanticSegmentation\x12R\n\rtext_to_image\x18\x07 \x01(\x0b\x32&.model.model.v1alpha.TextToImageOutputB\x04\xe2\x41\x01\x03H\x00R\x0btextToImage\x12U\n\x0eimage_to_image\x18\x08 \x01(\x0b\x32\'.model.model.v1alpha.ImageToImageOutputB\x04\xe2\x41\x01\x03H\x00R\x0cimageToImage\x12Z\n\x0ftext_generation\x18\t \x01(\x0b\x32).model.model.v1alpha.TextGenerationOutputB\x04\xe2\x41\x01\x03H\x00R\x0etextGeneration\x12g\n\x14text_generation_chat\x18\n \x01(\x0b\x32-.model.model.v1alpha.TextGenerationChatOutputB\x04\xe2\x41\x01\x03H\x00R\x12textGenerationChat\x12v\n\x19visual_question_answering\x18\x0b \x01(\x0b\x32\x32.model.model.v1alpha.VisualQuestionAnsweringOutputB\x04\xe2\x41\x01\x03H\x00R\x17visualQuestionAnswering\x12P\n\x0bunspecified\x18\x0c \x01(\x0b\x32&.model.model.v1alpha.UnspecifiedOutputB\x04\xe2\x41\x01\x03H\x00R\x0bunspecifiedB\x08\n\x06output\"\xad\x01\n\x17TriggerUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x45\n\x0btask_inputs\x18\x02 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\"\x8d\x01\n\x18TriggerUserModelResponse\x12-\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskR\x04task\x12\x42\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputR\x0btaskOutputs\"\xc1\x01\n\'TriggerUserModelBinaryFileUploadRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12I\n\ntask_input\x18\x02 \x01(\x0b\x32$.model.model.v1alpha.TaskInputStreamB\x04\xe2\x41\x01\x02R\ttaskInput\"\xa9\x01\n(TriggerUserModelBinaryFileUploadResponse\x12\x33\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x04\xe2\x41\x01\x02R\x04task\x12H\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputB\x04\xe2\x41\x01\x02R\x0btaskOutputs\"\xa5\x01\n\x1e\x43reateOrganizationModelRequest\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\x12Q\n\x06parent\x18\x02 \x01(\tB9\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\"d\n\x1f\x43reateOrganizationModelResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xdb\x01\n.CreateOrganizationModelBinaryFileUploadRequest\x12\x36\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x04\xe2\x41\x01\x02R\x05model\x12\x1e\n\x07\x63ontent\x18\x02 \x01(\x0c\x42\x04\xe2\x41\x01\x02R\x07\x63ontent\x12Q\n\x06parent\x18\x03 \x01(\tB9\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\"t\n/CreateOrganizationModelBinaryFileUploadResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xe3\x02\n\x1dListOrganizationModelsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x38\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12Q\n\x06parent\x18\x04 \x01(\tB9\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\x12,\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x03R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deleted\"\x9b\x01\n\x1eListOrganizationModelsResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelR\x06models\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xb5\x01\n\x1bGetOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"P\n\x1cGetOrganizationModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\x9b\x01\n\x1eUpdateOrganizationModelRequest\x12\x36\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x04\xe2\x41\x01\x02R\x05model\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"S\n\x1fUpdateOrganizationModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"u\n\x1e\x44\x65leteOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"!\n\x1f\x44\x65leteOrganizationModelResponse\"\x9d\x01\n\x1eRenameOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12&\n\x0cnew_model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\nnewModelId\"S\n\x1fRenameOrganizationModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"v\n\x1fPublishOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"T\n PublishOrganizationModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"x\n!UnpublishOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"V\n\"UnpublishOrganizationModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"u\n\x1e\x44\x65ployOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"<\n\x1f\x44\x65ployOrganizationModelResponse\x12\x19\n\x08model_id\x18\x01 \x01(\tR\x07modelId\"w\n UndeployOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\">\n!UndeployOrganizationModelResponse\x12\x19\n\x08model_id\x18\x01 \x01(\tR\x07modelId\"\x7f\n\x1fGetOrganizationModelCardRequest\x12\\\n\x04name\x18\x01 \x01(\tBH\x92\x41\"\xca>\x1f\xfa\x02\x1corganization_model_card_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ModelCardR\x04name\"Z\n GetOrganizationModelCardResponse\x12\x36\n\x06readme\x18\x01 \x01(\x0b\x32\x1e.model.model.v1alpha.ModelCardR\x06readme\"t\n\x1dWatchOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"t\n\x1eWatchOrganizationModelResponse\x12\x36\n\x05state\x18\x01 \x01(\x0e\x32 .model.model.v1alpha.Model.StateR\x05state\x12\x1a\n\x08progress\x18\x02 \x01(\x05R\x08progress\"\xbd\x01\n\x1fTriggerOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x45\n\x0btask_inputs\x18\x02 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\"\x95\x01\n TriggerOrganizationModelResponse\x12-\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskR\x04task\x12\x42\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputR\x0btaskOutputs\"\xd1\x01\n/TriggerOrganizationModelBinaryFileUploadRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12I\n\ntask_input\x18\x02 \x01(\x0b\x32$.model.model.v1alpha.TaskInputStreamB\x04\xe2\x41\x01\x02R\ttaskInput\"\xb1\x01\n0TriggerOrganizationModelBinaryFileUploadResponse\x12\x33\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x04\xe2\x41\x01\x02R\x04task\x12H\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputB\x04\xe2\x41\x01\x02R\x0btaskOutputs\"y\n\x18GetModelOperationRequest\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x04name\x12:\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x06\x18\x01\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"X\n\x19GetModelOperationResponse\x12;\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationR\toperation\"\x89\x02\n\x16ListModelsAdminRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x38\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12,\n\x0cshow_deleted\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x03R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deleted\"\x94\x01\n\x17ListModelsAdminResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelR\x06models\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x80\x01\n\x17LookUpModelAdminRequest\x12\"\n\tpermalink\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\tpermalink\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"L\n\x18LookUpModelAdminResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"G\n\x16\x43heckModelAdminRequest\x12-\n\x0fmodel_permalink\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0emodelPermalink\"Q\n\x17\x43heckModelAdminResponse\x12\x36\n\x05state\x18\x01 \x01(\x0e\x32 .model.model.v1alpha.Model.StateR\x05state\"H\n\x17\x44\x65ployModelAdminRequest\x12-\n\x0fmodel_permalink\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0emodelPermalink\"W\n\x18\x44\x65ployModelAdminResponse\x12;\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationR\toperation\"J\n\x19UndeployModelAdminRequest\x12-\n\x0fmodel_permalink\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0emodelPermalink\"Y\n\x1aUndeployModelAdminResponse\x12;\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationR\toperationB\xd7\x01\n\x17\x63om.model.model.v1alphaB\nModelProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\nModelProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _MODEL.fields_by_name['name']._options = None
  _MODEL.fields_by_name['name']._serialized_options = b'\222A\020\312>\r\372\002\nmodel_name\342A\001\003'
  _MODEL.fields_by_name['uid']._options = None
  _MODEL.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['id']._options = None
  _MODEL.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _MODEL.fields_by_name['description']._options = None
  _MODEL.fields_by_name['description']._serialized_options = b'\342A\001\001'
  _MODEL.fields_by_name['model_definition']._options = None
  _MODEL.fields_by_name['model_definition']._serialized_options = b'\342A\001\005\372A\"\n api.instill.tech/ModelDefinition'
  _MODEL.fields_by_name['configuration']._options = None
  _MODEL.fields_by_name['configuration']._serialized_options = b'\342A\001\005'
  _MODEL.fields_by_name['task']._options = None
  _MODEL.fields_by_name['task']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['state']._options = None
  _MODEL.fields_by_name['state']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['visibility']._options = None
  _MODEL.fields_by_name['visibility']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['create_time']._options = None
  _MODEL.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['update_time']._options = None
  _MODEL.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['delete_time']._options = None
  _MODEL.fields_by_name['delete_time']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['owner_name']._options = None
  _MODEL.fields_by_name['owner_name']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['owner']._options = None
  _MODEL.fields_by_name['owner']._serialized_options = b'\342A\002\001\003'
  _MODEL._options = None
  _MODEL._serialized_options = b'\352AO\n\026api.instill.tech/Model\022!users/{user.id}/models/{model.id}\022\022models/{model.uid}'
  _MODELCARD.fields_by_name['name']._options = None
  _MODELCARD.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _MODELCARD.fields_by_name['size']._options = None
  _MODELCARD.fields_by_name['size']._serialized_options = b'\342A\001\003'
  _MODELCARD.fields_by_name['type']._options = None
  _MODELCARD.fields_by_name['type']._serialized_options = b'\342A\001\003'
  _MODELCARD.fields_by_name['content']._options = None
  _MODELCARD.fields_by_name['content']._serialized_options = b'\342A\001\003'
  _MODELCARD.fields_by_name['encoding']._options = None
  _MODELCARD.fields_by_name['encoding']._serialized_options = b'\342A\001\003'
  _MODELCARD._options = None
  _MODELCARD._serialized_options = b'\352AF\n\032api.instill.tech/ModelCard\022(users/{user.id}/models/{model.id}/readme'
  _LISTMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTMODELSREQUEST.fields_by_name['view']._options = None
  _LISTMODELSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTMODELSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTMODELSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LOOKUPMODELREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPMODELREQUEST.fields_by_name['permalink']._serialized_options = b'\342A\001\002'
  _LOOKUPMODELREQUEST.fields_by_name['view']._options = None
  _LOOKUPMODELREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _CREATEUSERMODELREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERMODELREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\030\022\026api.instill.tech/Model'
  _CREATEUSERMODELRESPONSE.fields_by_name['operation']._options = None
  _CREATEUSERMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _CREATEUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['model']._options = None
  _CREATEUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _CREATEUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['content']._options = None
  _CREATEUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['content']._serialized_options = b'\342A\001\002'
  _CREATEUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\030\022\026api.instill.tech/Model'
  _CREATEUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['operation']._options = None
  _CREATEUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _LISTUSERMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTUSERMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTUSERMODELSREQUEST.fields_by_name['view']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTUSERMODELSREQUEST.fields_by_name['parent']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\030\022\026api.instill.tech/Model'
  _LISTUSERMODELSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _GETUSERMODELREQUEST.fields_by_name['name']._options = None
  _GETUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _GETUSERMODELREQUEST.fields_by_name['view']._options = None
  _GETUSERMODELREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _UPDATEUSERMODELREQUEST.fields_by_name['model']._options = None
  _UPDATEUSERMODELREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _UPDATEUSERMODELREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERMODELREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEUSERMODELREQUEST.fields_by_name['name']._options = None
  _DELETEUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEUSERMODELREQUEST.fields_by_name['name']._options = None
  _RENAMEUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEUSERMODELREQUEST.fields_by_name['new_model_id']._options = None
  _RENAMEUSERMODELREQUEST.fields_by_name['new_model_id']._serialized_options = b'\342A\001\002'
  _PUBLISHUSERMODELREQUEST.fields_by_name['name']._options = None
  _PUBLISHUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _UNPUBLISHUSERMODELREQUEST.fields_by_name['name']._options = None
  _UNPUBLISHUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _DEPLOYUSERMODELREQUEST.fields_by_name['name']._options = None
  _DEPLOYUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _UNDEPLOYUSERMODELREQUEST.fields_by_name['name']._options = None
  _UNDEPLOYUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _GETUSERMODELCARDREQUEST.fields_by_name['name']._options = None
  _GETUSERMODELCARDREQUEST.fields_by_name['name']._serialized_options = b'\222A\032\312>\027\372\002\024user_model_card_name\342A\001\002\372A\034\n\032api.instill.tech/ModelCard'
  _WATCHUSERMODELREQUEST.fields_by_name['name']._options = None
  _WATCHUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TASKOUTPUT.fields_by_name['classification']._options = None
  _TASKOUTPUT.fields_by_name['classification']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['detection']._options = None
  _TASKOUTPUT.fields_by_name['detection']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['keypoint']._options = None
  _TASKOUTPUT.fields_by_name['keypoint']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['ocr']._options = None
  _TASKOUTPUT.fields_by_name['ocr']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['instance_segmentation']._options = None
  _TASKOUTPUT.fields_by_name['instance_segmentation']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['semantic_segmentation']._options = None
  _TASKOUTPUT.fields_by_name['semantic_segmentation']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['text_to_image']._options = None
  _TASKOUTPUT.fields_by_name['text_to_image']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['image_to_image']._options = None
  _TASKOUTPUT.fields_by_name['image_to_image']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['text_generation']._options = None
  _TASKOUTPUT.fields_by_name['text_generation']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['text_generation_chat']._options = None
  _TASKOUTPUT.fields_by_name['text_generation_chat']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['visual_question_answering']._options = None
  _TASKOUTPUT.fields_by_name['visual_question_answering']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['unspecified']._options = None
  _TASKOUTPUT.fields_by_name['unspecified']._serialized_options = b'\342A\001\003'
  _TRIGGERUSERMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERUSERMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERUSERMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._serialized_options = b'\342A\001\002'
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._serialized_options = b'\342A\001\002'
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\342A\001\002'
  _CREATEORGANIZATIONMODELREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONMODELREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\030\022\026api.instill.tech/Model'
  _CREATEORGANIZATIONMODELRESPONSE.fields_by_name['operation']._options = None
  _CREATEORGANIZATIONMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _CREATEORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['model']._options = None
  _CREATEORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _CREATEORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['content']._options = None
  _CREATEORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['content']._serialized_options = b'\342A\001\002'
  _CREATEORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\030\022\026api.instill.tech/Model'
  _CREATEORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['operation']._options = None
  _CREATEORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['view']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['parent']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\030\022\026api.instill.tech/Model'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _GETORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _GETORGANIZATIONMODELREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONMODELREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['model']._options = None
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['new_model_id']._options = None
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['new_model_id']._serialized_options = b'\342A\001\002'
  _PUBLISHORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _PUBLISHORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _UNPUBLISHORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _UNPUBLISHORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _DEPLOYORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _DEPLOYORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _UNDEPLOYORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _UNDEPLOYORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _GETORGANIZATIONMODELCARDREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONMODELCARDREQUEST.fields_by_name['name']._serialized_options = b'\222A\"\312>\037\372\002\034organization_model_card_name\342A\001\002\372A\034\n\032api.instill.tech/ModelCard'
  _WATCHORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _WATCHORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._serialized_options = b'\342A\001\002'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._serialized_options = b'\342A\001\002'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\342A\001\002'
  _GETMODELOPERATIONREQUEST.fields_by_name['name']._options = None
  _GETMODELOPERATIONREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002'
  _GETMODELOPERATIONREQUEST.fields_by_name['view']._options = None
  _GETMODELOPERATIONREQUEST.fields_by_name['view']._serialized_options = b'\030\001\342A\001\001'
  _LISTMODELSADMINREQUEST.fields_by_name['page_size']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTMODELSADMINREQUEST.fields_by_name['page_token']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTMODELSADMINREQUEST.fields_by_name['view']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTMODELSADMINREQUEST.fields_by_name['show_deleted']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LOOKUPMODELADMINREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPMODELADMINREQUEST.fields_by_name['permalink']._serialized_options = b'\342A\001\002'
  _LOOKUPMODELADMINREQUEST.fields_by_name['view']._options = None
  _LOOKUPMODELADMINREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _CHECKMODELADMINREQUEST.fields_by_name['model_permalink']._options = None
  _CHECKMODELADMINREQUEST.fields_by_name['model_permalink']._serialized_options = b'\342A\001\002'
  _DEPLOYMODELADMINREQUEST.fields_by_name['model_permalink']._options = None
  _DEPLOYMODELADMINREQUEST.fields_by_name['model_permalink']._serialized_options = b'\342A\001\002'
  _UNDEPLOYMODELADMINREQUEST.fields_by_name['model_permalink']._options = None
  _UNDEPLOYMODELADMINREQUEST.fields_by_name['model_permalink']._serialized_options = b'\342A\001\002'
  _globals['_LIVENESSREQUEST']._serialized_start=1019
  _globals['_LIVENESSREQUEST']._serialized_end=1169
  _globals['_LIVENESSRESPONSE']._serialized_start=1171
  _globals['_LIVENESSRESPONSE']._serialized_end=1289
  _globals['_READINESSREQUEST']._serialized_start=1292
  _globals['_READINESSREQUEST']._serialized_end=1443
  _globals['_READINESSRESPONSE']._serialized_start=1445
  _globals['_READINESSRESPONSE']._serialized_end=1564
  _globals['_MODEL']._serialized_start=1567
  _globals['_MODEL']._serialized_end=2645
  _globals['_MODEL_VISIBILITY']._serialized_start=2356
  _globals['_MODEL_VISIBILITY']._serialized_end=2443
  _globals['_MODEL_STATE']._serialized_start=2445
  _globals['_MODEL_STATE']._serialized_end=2529
  _globals['_MODELCARD']._serialized_start=2648
  _globals['_MODELCARD']._serialized_end=2878
  _globals['_LISTMODELSREQUEST']._serialized_start=2881
  _globals['_LISTMODELSREQUEST']._serialized_end=3141
  _globals['_LISTMODELSRESPONSE']._serialized_start=3144
  _globals['_LISTMODELSRESPONSE']._serialized_end=3287
  _globals['_LOOKUPMODELREQUEST']._serialized_start=3289
  _globals['_LOOKUPMODELREQUEST']._serialized_end=3412
  _globals['_LOOKUPMODELRESPONSE']._serialized_start=3414
  _globals['_LOOKUPMODELRESPONSE']._serialized_end=3485
  _globals['_CREATEUSERMODELREQUEST']._serialized_start=3488
  _globals['_CREATEUSERMODELREQUEST']._serialized_end=3637
  _globals['_CREATEUSERMODELRESPONSE']._serialized_start=3639
  _globals['_CREATEUSERMODELRESPONSE']._serialized_end=3731
  _globals['_CREATEUSERMODELBINARYFILEUPLOADREQUEST']._serialized_start=3734
  _globals['_CREATEUSERMODELBINARYFILEUPLOADREQUEST']._serialized_end=3937
  _globals['_CREATEUSERMODELBINARYFILEUPLOADRESPONSE']._serialized_start=3939
  _globals['_CREATEUSERMODELBINARYFILEUPLOADRESPONSE']._serialized_end=4047
  _globals['_LISTUSERMODELSREQUEST']._serialized_start=4050
  _globals['_LISTUSERMODELSREQUEST']._serialized_end=4389
  _globals['_LISTUSERMODELSRESPONSE']._serialized_start=4392
  _globals['_LISTUSERMODELSRESPONSE']._serialized_end=4539
  _globals['_GETUSERMODELREQUEST']._serialized_start=4542
  _globals['_GETUSERMODELREQUEST']._serialized_end=4707
  _globals['_GETUSERMODELRESPONSE']._serialized_start=4709
  _globals['_GETUSERMODELRESPONSE']._serialized_end=4781
  _globals['_UPDATEUSERMODELREQUEST']._serialized_start=4784
  _globals['_UPDATEUSERMODELREQUEST']._serialized_end=4931
  _globals['_UPDATEUSERMODELRESPONSE']._serialized_start=4933
  _globals['_UPDATEUSERMODELRESPONSE']._serialized_end=5008
  _globals['_DELETEUSERMODELREQUEST']._serialized_start=5010
  _globals['_DELETEUSERMODELREQUEST']._serialized_end=5111
  _globals['_DELETEUSERMODELRESPONSE']._serialized_start=5113
  _globals['_DELETEUSERMODELRESPONSE']._serialized_end=5138
  _globals['_RENAMEUSERMODELREQUEST']._serialized_start=5141
  _globals['_RENAMEUSERMODELREQUEST']._serialized_end=5282
  _globals['_RENAMEUSERMODELRESPONSE']._serialized_start=5284
  _globals['_RENAMEUSERMODELRESPONSE']._serialized_end=5359
  _globals['_PUBLISHUSERMODELREQUEST']._serialized_start=5361
  _globals['_PUBLISHUSERMODELREQUEST']._serialized_end=5463
  _globals['_PUBLISHUSERMODELRESPONSE']._serialized_start=5465
  _globals['_PUBLISHUSERMODELRESPONSE']._serialized_end=5541
  _globals['_UNPUBLISHUSERMODELREQUEST']._serialized_start=5543
  _globals['_UNPUBLISHUSERMODELREQUEST']._serialized_end=5647
  _globals['_UNPUBLISHUSERMODELRESPONSE']._serialized_start=5649
  _globals['_UNPUBLISHUSERMODELRESPONSE']._serialized_end=5727
  _globals['_DEPLOYUSERMODELREQUEST']._serialized_start=5729
  _globals['_DEPLOYUSERMODELREQUEST']._serialized_end=5830
  _globals['_DEPLOYUSERMODELRESPONSE']._serialized_start=5832
  _globals['_DEPLOYUSERMODELRESPONSE']._serialized_end=5884
  _globals['_UNDEPLOYUSERMODELREQUEST']._serialized_start=5886
  _globals['_UNDEPLOYUSERMODELREQUEST']._serialized_end=5989
  _globals['_UNDEPLOYUSERMODELRESPONSE']._serialized_start=5991
  _globals['_UNDEPLOYUSERMODELRESPONSE']._serialized_end=6045
  _globals['_GETUSERMODELCARDREQUEST']._serialized_start=6047
  _globals['_GETUSERMODELCARDREQUEST']._serialized_end=6158
  _globals['_GETUSERMODELCARDRESPONSE']._serialized_start=6160
  _globals['_GETUSERMODELCARDRESPONSE']._serialized_end=6242
  _globals['_WATCHUSERMODELREQUEST']._serialized_start=6244
  _globals['_WATCHUSERMODELREQUEST']._serialized_end=6344
  _globals['_WATCHUSERMODELRESPONSE']._serialized_start=6346
  _globals['_WATCHUSERMODELRESPONSE']._serialized_end=6454
  _globals['_TASKINPUT']._serialized_start=6457
  _globals['_TASKINPUT']._serialized_end=7481
  _globals['_TASKINPUTSTREAM']._serialized_start=7484
  _globals['_TASKINPUTSTREAM']._serialized_end=8550
  _globals['_TASKOUTPUT']._serialized_start=8553
  _globals['_TASKOUTPUT']._serialized_end=9663
  _globals['_TRIGGERUSERMODELREQUEST']._serialized_start=9666
  _globals['_TRIGGERUSERMODELREQUEST']._serialized_end=9839
  _globals['_TRIGGERUSERMODELRESPONSE']._serialized_start=9842
  _globals['_TRIGGERUSERMODELRESPONSE']._serialized_end=9983
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADREQUEST']._serialized_start=9986
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADREQUEST']._serialized_end=10179
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE']._serialized_start=10182
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE']._serialized_end=10351
  _globals['_CREATEORGANIZATIONMODELREQUEST']._serialized_start=10354
  _globals['_CREATEORGANIZATIONMODELREQUEST']._serialized_end=10519
  _globals['_CREATEORGANIZATIONMODELRESPONSE']._serialized_start=10521
  _globals['_CREATEORGANIZATIONMODELRESPONSE']._serialized_end=10621
  _globals['_CREATEORGANIZATIONMODELBINARYFILEUPLOADREQUEST']._serialized_start=10624
  _globals['_CREATEORGANIZATIONMODELBINARYFILEUPLOADREQUEST']._serialized_end=10843
  _globals['_CREATEORGANIZATIONMODELBINARYFILEUPLOADRESPONSE']._serialized_start=10845
  _globals['_CREATEORGANIZATIONMODELBINARYFILEUPLOADRESPONSE']._serialized_end=10961
  _globals['_LISTORGANIZATIONMODELSREQUEST']._serialized_start=10964
  _globals['_LISTORGANIZATIONMODELSREQUEST']._serialized_end=11319
  _globals['_LISTORGANIZATIONMODELSRESPONSE']._serialized_start=11322
  _globals['_LISTORGANIZATIONMODELSRESPONSE']._serialized_end=11477
  _globals['_GETORGANIZATIONMODELREQUEST']._serialized_start=11480
  _globals['_GETORGANIZATIONMODELREQUEST']._serialized_end=11661
  _globals['_GETORGANIZATIONMODELRESPONSE']._serialized_start=11663
  _globals['_GETORGANIZATIONMODELRESPONSE']._serialized_end=11743
  _globals['_UPDATEORGANIZATIONMODELREQUEST']._serialized_start=11746
  _globals['_UPDATEORGANIZATIONMODELREQUEST']._serialized_end=11901
  _globals['_UPDATEORGANIZATIONMODELRESPONSE']._serialized_start=11903
  _globals['_UPDATEORGANIZATIONMODELRESPONSE']._serialized_end=11986
  _globals['_DELETEORGANIZATIONMODELREQUEST']._serialized_start=11988
  _globals['_DELETEORGANIZATIONMODELREQUEST']._serialized_end=12105
  _globals['_DELETEORGANIZATIONMODELRESPONSE']._serialized_start=12107
  _globals['_DELETEORGANIZATIONMODELRESPONSE']._serialized_end=12140
  _globals['_RENAMEORGANIZATIONMODELREQUEST']._serialized_start=12143
  _globals['_RENAMEORGANIZATIONMODELREQUEST']._serialized_end=12300
  _globals['_RENAMEORGANIZATIONMODELRESPONSE']._serialized_start=12302
  _globals['_RENAMEORGANIZATIONMODELRESPONSE']._serialized_end=12385
  _globals['_PUBLISHORGANIZATIONMODELREQUEST']._serialized_start=12387
  _globals['_PUBLISHORGANIZATIONMODELREQUEST']._serialized_end=12505
  _globals['_PUBLISHORGANIZATIONMODELRESPONSE']._serialized_start=12507
  _globals['_PUBLISHORGANIZATIONMODELRESPONSE']._serialized_end=12591
  _globals['_UNPUBLISHORGANIZATIONMODELREQUEST']._serialized_start=12593
  _globals['_UNPUBLISHORGANIZATIONMODELREQUEST']._serialized_end=12713
  _globals['_UNPUBLISHORGANIZATIONMODELRESPONSE']._serialized_start=12715
  _globals['_UNPUBLISHORGANIZATIONMODELRESPONSE']._serialized_end=12801
  _globals['_DEPLOYORGANIZATIONMODELREQUEST']._serialized_start=12803
  _globals['_DEPLOYORGANIZATIONMODELREQUEST']._serialized_end=12920
  _globals['_DEPLOYORGANIZATIONMODELRESPONSE']._serialized_start=12922
  _globals['_DEPLOYORGANIZATIONMODELRESPONSE']._serialized_end=12982
  _globals['_UNDEPLOYORGANIZATIONMODELREQUEST']._serialized_start=12984
  _globals['_UNDEPLOYORGANIZATIONMODELREQUEST']._serialized_end=13103
  _globals['_UNDEPLOYORGANIZATIONMODELRESPONSE']._serialized_start=13105
  _globals['_UNDEPLOYORGANIZATIONMODELRESPONSE']._serialized_end=13167
  _globals['_GETORGANIZATIONMODELCARDREQUEST']._serialized_start=13169
  _globals['_GETORGANIZATIONMODELCARDREQUEST']._serialized_end=13296
  _globals['_GETORGANIZATIONMODELCARDRESPONSE']._serialized_start=13298
  _globals['_GETORGANIZATIONMODELCARDRESPONSE']._serialized_end=13388
  _globals['_WATCHORGANIZATIONMODELREQUEST']._serialized_start=13390
  _globals['_WATCHORGANIZATIONMODELREQUEST']._serialized_end=13506
  _globals['_WATCHORGANIZATIONMODELRESPONSE']._serialized_start=13508
  _globals['_WATCHORGANIZATIONMODELRESPONSE']._serialized_end=13624
  _globals['_TRIGGERORGANIZATIONMODELREQUEST']._serialized_start=13627
  _globals['_TRIGGERORGANIZATIONMODELREQUEST']._serialized_end=13816
  _globals['_TRIGGERORGANIZATIONMODELRESPONSE']._serialized_start=13819
  _globals['_TRIGGERORGANIZATIONMODELRESPONSE']._serialized_end=13968
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST']._serialized_start=13971
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST']._serialized_end=14180
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE']._serialized_start=14183
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE']._serialized_end=14360
  _globals['_GETMODELOPERATIONREQUEST']._serialized_start=14362
  _globals['_GETMODELOPERATIONREQUEST']._serialized_end=14483
  _globals['_GETMODELOPERATIONRESPONSE']._serialized_start=14485
  _globals['_GETMODELOPERATIONRESPONSE']._serialized_end=14573
  _globals['_LISTMODELSADMINREQUEST']._serialized_start=14576
  _globals['_LISTMODELSADMINREQUEST']._serialized_end=14841
  _globals['_LISTMODELSADMINRESPONSE']._serialized_start=14844
  _globals['_LISTMODELSADMINRESPONSE']._serialized_end=14992
  _globals['_LOOKUPMODELADMINREQUEST']._serialized_start=14995
  _globals['_LOOKUPMODELADMINREQUEST']._serialized_end=15123
  _globals['_LOOKUPMODELADMINRESPONSE']._serialized_start=15125
  _globals['_LOOKUPMODELADMINRESPONSE']._serialized_end=15201
  _globals['_CHECKMODELADMINREQUEST']._serialized_start=15203
  _globals['_CHECKMODELADMINREQUEST']._serialized_end=15274
  _globals['_CHECKMODELADMINRESPONSE']._serialized_start=15276
  _globals['_CHECKMODELADMINRESPONSE']._serialized_end=15357
  _globals['_DEPLOYMODELADMINREQUEST']._serialized_start=15359
  _globals['_DEPLOYMODELADMINREQUEST']._serialized_end=15431
  _globals['_DEPLOYMODELADMINRESPONSE']._serialized_start=15433
  _globals['_DEPLOYMODELADMINRESPONSE']._serialized_end=15520
  _globals['_UNDEPLOYMODELADMINREQUEST']._serialized_start=15522
  _globals['_UNDEPLOYMODELADMINREQUEST']._serialized_end=15596
  _globals['_UNDEPLOYMODELADMINRESPONSE']._serialized_start=15598
  _globals['_UNDEPLOYMODELADMINRESPONSE']._serialized_end=15687
# @@protoc_insertion_point(module_scope)



# generated by datamodel-codegen:
#   filename:  text_task_convert_to_text_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict


@dataclass
class Output:
    body: str
    error: str
    meta: Dict[str, Any]
    msecs: float



# generated by datamodel-codegen:
#   filename:  redis_task_chat_message_write_multi_modal_output.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Output:
    status: bool



# pylint: disable=no-member,wrong-import-position,no-name-in-module
from typing import Tuple, Union

import grpc
from google.longrunning import operations_pb2
from google.protobuf.field_mask_pb2 import FieldMask

import instill.protogen.vdp.pipeline.v1beta.pipeline_pb2 as pipeline_interface
from instill.clients import InstillClient
from instill.resources.resource import Resource
from instill.utils.logger import Logger


class Pipeline(Resource):
    def __init__(
        self,
        client: InstillClient,
        name: str,
        recipe: Union[pipeline_interface.Recipe, None] = None,
    ) -> None:
        super().__init__()
        self.client = client
        get_resp = client.pipeline_service.get_pipeline(name=name, silent=True)
        if get_resp is None:
            pipeline = client.pipeline_service.create_pipeline(
                name=name, recipe=recipe
            ).pipeline
            if pipeline is None:
                raise BaseException("pipeline creation failed")
        else:
            pipeline = get_resp.pipeline

        self.resource = pipeline

    def __call__(
        self, task_inputs: list
    ) -> Tuple[list, pipeline_interface.TriggerMetadata]:
        resp = self.client.pipeline_service.trigger_pipeline(
            self.resource.id, task_inputs
        )
        return resp.outputs, resp.metadata

    @property
    def client(self):
        return self._client

    @client.setter
    def client(self, client: InstillClient):
        self._client = client

    @property
    def resource(self):
        return self._resource

    @resource.setter
    def resource(self, resource: pipeline_interface.Pipeline):
        self._resource = resource

    def _update(self):
        self.resource = self.client.pipeline_service.get_pipeline(name=self.resource.id)

    def get_operation(self, operation: operations_pb2.Operation):
        return self.client.pipeline_service.get_operation(operation.name).operation

    def trigger_async(self, task_inputs: list) -> operations_pb2.Operation:
        return self.client.pipeline_service.trigger_async_pipeline(
            self.resource.id, task_inputs
        ).operation

    def get_recipe(self) -> pipeline_interface.Recipe:
        return self.resource.recipe

    def update_recipe(self, recipe: pipeline_interface.Recipe):
        pipeline = self.resource
        pipeline.recipe.CopyFrom(recipe)
        self.client.pipeline_service.update_pipeline(
            pipeline, FieldMask(paths=["recipe"])
        )
        self._update()

    def validate_pipeline(self) -> bool:
        try:
            self.client.pipeline_service.validate_pipeline(
                name=self.resource.id, silent=True
            )
            return True
        except grpc.RpcError as rpc_error:
            Logger.w(rpc_error.code())
            Logger.w(rpc_error.details())
            return False

    def delete(self):
        if self.resource is not None:
            self.client.pipeline_service.delete_pipeline(self.resource.id)



# generated by datamodel-codegen:
#   filename:  openai_definitions.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class OpenAIConnectorResource:
    api_key: str
    organization: Optional[str] = None



# generated by datamodel-codegen:
#   filename:  huggingface_task_question_answering_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class Output:
    answer: str
    score: Optional[float] = None
    start: Optional[int] = None
    stop: Optional[int] = None



# generated by datamodel-codegen:
#   filename:  numbers_definitions.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class NumbersProtocolBlockchainConnectorSpec:
    capture_token: str



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import common.healthcheck.v1beta.healthcheck_pb2
import google.protobuf.descriptor
import google.protobuf.message
import model.model.v1alpha.model_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class LivenessRequest(google.protobuf.message.Message):
    """LivenessRequest represents a request to check a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___LivenessRequest = LivenessRequest

@typing_extensions.final
class LivenessResponse(google.protobuf.message.Message):
    """LivenessResponse represents a response for a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___LivenessResponse = LivenessResponse

@typing_extensions.final
class ReadinessRequest(google.protobuf.message.Message):
    """ReadinessRequest represents a request to check a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___ReadinessRequest = ReadinessRequest

@typing_extensions.final
class ReadinessResponse(google.protobuf.message.Message):
    """ReadinessResponse represents a response for a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___ReadinessResponse = ReadinessResponse

@typing_extensions.final
class Resource(google.protobuf.message.Message):
    """Resource represents the current information of a resource"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PERMALINK_FIELD_NUMBER: builtins.int
    MODEL_STATE_FIELD_NUMBER: builtins.int
    BACKEND_STATE_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    resource_permalink: builtins.str
    """Permalink of a resource. For example:
    "resources/{resource_uuid}/types/{type}"
    """
    model_state: model.model.v1alpha.model_pb2.Model.State.ValueType
    """Model state"""
    backend_state: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse.ServingStatus.ValueType
    """Backend service state"""
    progress: builtins.int
    """Resource longrunning progress"""
    workflow_id: builtins.str
    """Resource longrunning workflow id"""
    def __init__(
        self,
        *,
        resource_permalink: builtins.str = ...,
        model_state: model.model.v1alpha.model_pb2.Model.State.ValueType = ...,
        backend_state: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse.ServingStatus.ValueType = ...,
        progress: builtins.int | None = ...,
        workflow_id: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_progress", b"_progress", "_workflow_id", b"_workflow_id", "backend_state", b"backend_state", "model_state", b"model_state", "progress", b"progress", "state", b"state", "workflow_id", b"workflow_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_progress", b"_progress", "_workflow_id", b"_workflow_id", "backend_state", b"backend_state", "model_state", b"model_state", "progress", b"progress", "resource_permalink", b"resource_permalink", "state", b"state", "workflow_id", b"workflow_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_progress", b"_progress"]) -> typing_extensions.Literal["progress"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_workflow_id", b"_workflow_id"]) -> typing_extensions.Literal["workflow_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["state", b"state"]) -> typing_extensions.Literal["model_state", "backend_state"] | None: ...

global___Resource = Resource

@typing_extensions.final
class GetResourceRequest(google.protobuf.message.Message):
    """GetResourceRequest represents a request to query a resource's state"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PERMALINK_FIELD_NUMBER: builtins.int
    resource_permalink: builtins.str
    """Permalink of a resource. For example:
    "resources/{resource_uuid}/types/{type}"
    """
    def __init__(
        self,
        *,
        resource_permalink: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_permalink", b"resource_permalink"]) -> None: ...

global___GetResourceRequest = GetResourceRequest

@typing_extensions.final
class GetResourceResponse(google.protobuf.message.Message):
    """GetResourceResponse represents a response to fetch a resource's state"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource(self) -> global___Resource:
        """Retrieved resource state"""
    def __init__(
        self,
        *,
        resource: global___Resource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource", b"resource"]) -> None: ...

global___GetResourceResponse = GetResourceResponse

@typing_extensions.final
class UpdateResourceRequest(google.protobuf.message.Message):
    """UpdateResourceRequest represents a request to update a resource's state"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource(self) -> global___Resource:
        """Resource state"""
    def __init__(
        self,
        *,
        resource: global___Resource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource", b"resource"]) -> None: ...

global___UpdateResourceRequest = UpdateResourceRequest

@typing_extensions.final
class UpdateResourceResponse(google.protobuf.message.Message):
    """UpdateResourceResponse represents a response to update a resource's state"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource(self) -> global___Resource:
        """Updated resource state"""
    def __init__(
        self,
        *,
        resource: global___Resource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource", b"resource"]) -> None: ...

global___UpdateResourceResponse = UpdateResourceResponse

@typing_extensions.final
class DeleteResourceRequest(google.protobuf.message.Message):
    """DeleteResourceRequest represents a request to delete a resource's state"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PERMALINK_FIELD_NUMBER: builtins.int
    resource_permalink: builtins.str
    """Permalink of a resource. For example:
    "resources/{resource_uuid}/types/{type}"
    """
    def __init__(
        self,
        *,
        resource_permalink: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_permalink", b"resource_permalink"]) -> None: ...

global___DeleteResourceRequest = DeleteResourceRequest

@typing_extensions.final
class DeleteResourceResponse(google.protobuf.message.Message):
    """DeleteResourceResponse represents an empty response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteResourceResponse = DeleteResourceResponse



# pylint: disable=no-member,wrong-import-position,no-name-in-module,arguments-renamed
import json
from typing import Union

import jsonschema

from instill.clients import InstillClient
from instill.protogen.vdp.pipeline.v1beta.pipeline_pb2 import Component
from instill.resources import const
from instill.resources.connector import Connector
from instill.resources.schema import (
    helper,
    huggingface_task_audio_classification_input,
    huggingface_task_conversational_input,
    huggingface_task_fill_mask_input,
    huggingface_task_image_classification_input,
    huggingface_task_image_segmentation_input,
    huggingface_task_image_to_text_input,
    huggingface_task_object_detection_input,
    huggingface_task_question_answering_input,
    huggingface_task_sentence_similarity_input,
    huggingface_task_speech_recognition_input,
    huggingface_task_summarization_input,
    huggingface_task_table_question_answering_input,
    huggingface_task_text_classification_input,
    huggingface_task_text_generation_input,
    huggingface_task_text_to_image_input,
    huggingface_task_token_classification_input,
    huggingface_task_translation_input,
    huggingface_task_zero_shot_classification_input,
    instill_task_classification_input,
    instill_task_detection_input,
    instill_task_image_to_image_input,
    instill_task_instance_segmentation_input,
    instill_task_keypoint_input,
    instill_task_ocr_input,
    instill_task_semantic_segmentation_input,
    instill_task_text_generation_input,
    instill_task_text_to_image_input,
    instill_task_visual_question_answering_input,
    openai_task_speech_recognition_input,
    openai_task_text_embeddings_input,
    openai_task_text_generation_input,
    openai_task_text_to_image_input,
    openai_task_text_to_speech_input,
    stabilityai_task_image_to_image_input,
    stabilityai_task_text_to_image_input,
)
from instill.resources.schema.huggingface import HuggingFaceConnectorSpec
from instill.resources.schema.instill import (
    InstillModelConnector as InstillModelConnectorConfig,
)
from instill.resources.schema.openai import OpenAIConnectorResource
from instill.resources.schema.stabilityai import StabilityAIConnectorResource


class HuggingfaceConnector(Connector):
    """Huggingface Connector"""

    with open(
        f"{const.SPEC_PATH}/huggingface_definitions.json", "r", encoding="utf8"
    ) as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: HuggingFaceConnectorSpec,
    ) -> None:
        definition = "connector-definitions/hugging-face"

        config_dict = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_dict, StabilityAIConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_dict)

    def create_component(
        self,
        name: str,
        inp: Union[
            huggingface_task_audio_classification_input.Input,
            huggingface_task_conversational_input.Input,
            huggingface_task_fill_mask_input.Input,
            huggingface_task_image_classification_input.Input,
            huggingface_task_image_segmentation_input.Input,
            huggingface_task_object_detection_input.Input,
            huggingface_task_image_to_text_input.Input,
            huggingface_task_question_answering_input.Input,
            huggingface_task_sentence_similarity_input.Input,
            huggingface_task_speech_recognition_input.Input,
            huggingface_task_summarization_input.Input,
            huggingface_task_table_question_answering_input.Input,
            huggingface_task_text_generation_input.Input,
            huggingface_task_text_classification_input.Input,
            huggingface_task_text_to_image_input.Input,
            huggingface_task_translation_input.Input,
            huggingface_task_zero_shot_classification_input.Input,
            huggingface_task_token_classification_input.Input,
        ],
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class InstillModelConnector(Connector):
    """Instill Model Connector"""

    with open(f"{const.SPEC_PATH}/instill_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        config: InstillModelConnectorConfig,
        name: str = "model-connector",
    ) -> None:
        definition = "connector-definitions/instill-model"

        config_dict = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_dict, InstillModelConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_dict)

    def create_component(
        self,
        name: str,
        inp: Union[
            instill_task_classification_input.Input,
            instill_task_detection_input.Input,
            instill_task_instance_segmentation_input.Input,
            instill_task_semantic_segmentation_input.Input,
            instill_task_keypoint_input.Input,
            instill_task_ocr_input.Input,
            instill_task_image_to_image_input.Input,
            instill_task_text_generation_input.Input,
            instill_task_text_to_image_input.Input,
            instill_task_visual_question_answering_input.Input,
        ],
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class StabilityAIConnector(Connector):
    """Stability AI Connector"""

    with open(
        f"{const.SPEC_PATH}/stabilityai_definitions.json", "r", encoding="utf8"
    ) as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: StabilityAIConnectorResource,
    ) -> None:
        definition = "connector-definitions/stability-ai"

        config_dict = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_dict, StabilityAIConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_dict)

    def create_component(
        self,
        name: str,
        inp: Union[
            stabilityai_task_image_to_image_input.Input,
            stabilityai_task_text_to_image_input.Input,
        ],
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class OpenAIConnector(Connector):
    """OpenAI Connector"""

    with open(f"{const.SPEC_PATH}/openai_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: OpenAIConnectorResource,
    ) -> None:
        definition = "connector-definitions/openai"

        config_dict = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_dict, OpenAIConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_dict)

    def create_component(
        self,
        name: str,
        inp: Union[
            openai_task_speech_recognition_input.Input,
            openai_task_text_embeddings_input.Input,
            openai_task_text_to_image_input.Input,
            openai_task_text_generation_input.Input,
            openai_task_text_to_speech_input.Input,
        ],
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)



# generated by datamodel-codegen:
#   filename:  numbers_task_register_input.json

from __future__ import annotations

from dataclasses import dataclass
from enum import Enum
from typing import List, Optional


class DigitalSourceType(Enum):
    trainedAlgorithmicMedia = 'trainedAlgorithmicMedia'
    trainedAlgorithmicData = 'trainedAlgorithmicData'
    digitalCapture = 'digitalCapture'
    digitalArt = 'digitalArt'
    algorithmicMedia = 'algorithmicMedia'


@dataclass
class License:
    document: Optional[str] = None
    name: Optional[str] = None


class MiningPreference(Enum):
    dataMining = 'dataMining'
    aiInference = 'aiInference'
    notAllowed = 'notAllowed'
    aiGenerativeTraining = 'aiGenerativeTraining'
    aiGenerativeTrainingWithAuthorship = 'aiGenerativeTrainingWithAuthorship'
    aiTraining = 'aiTraining'
    aiTrainingWithAuthorship = 'aiTrainingWithAuthorship'


@dataclass
class Input:
    images: List[str]
    headline: Optional[str] = None
    caption: Optional[str] = None
    asset_creator: Optional[str] = None
    digital_source_type: Optional[
        DigitalSourceType
    ] = DigitalSourceType.trainedAlgorithmicMedia
    generated_by: Optional[str] = None
    license: Optional[License] = None
    mining_preference: Optional[MiningPreference] = MiningPreference.notAllowed



# generated by datamodel-codegen:
#   filename:  instill_task_image_to_image_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict, Optional


@dataclass
class Input:
    image_base64: str
    model_name: str
    prompt: str
    cfg_scale: Optional[float] = None
    extra_params: Optional[Dict[str, Any]] = None
    samples: Optional[int] = None
    seed: Optional[int] = None
    top_k: Optional[int] = 10



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2


class MgmtPrivateServiceStub(object):
    """Mgmt service responds to internal access
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListUsersAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/ListUsersAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminResponse.FromString,
                )
        self.GetUserAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/GetUserAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminResponse.FromString,
                )
        self.LookUpUserAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/LookUpUserAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminResponse.FromString,
                )
        self.ListOrganizationsAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/ListOrganizationsAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminResponse.FromString,
                )
        self.GetOrganizationAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/GetOrganizationAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminResponse.FromString,
                )
        self.LookUpOrganizationAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/LookUpOrganizationAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminResponse.FromString,
                )
        self.GetUserSubscriptionAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/GetUserSubscriptionAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminResponse.FromString,
                )
        self.GetOrganizationSubscriptionAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/GetOrganizationSubscriptionAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminResponse.FromString,
                )


class MgmtPrivateServiceServicer(object):
    """Mgmt service responds to internal access
    """

    def ListUsersAdmin(self, request, context):
        """ListUsersAdmin method receives a ListUsersAdminRequest message and returns
        a ListUsersAdminResponse message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserAdmin(self, request, context):
        """GetUserAdmin method receives a GetUserAdminRequest message and returns
        a GetUserAdminResponse message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookUpUserAdmin(self, request, context):
        """LookUpUserAdmin method receives a LookUpUserAdminRequest message and
        returns a LookUpUserAdminResponse
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationsAdmin(self, request, context):
        """ListOrganizationsAdmin method receives a ListOrganizationsAdminRequest message and returns
        a ListOrganizationsAdminResponse message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationAdmin(self, request, context):
        """GetOrganizationAdmin method receives a GetOrganizationAdminRequest message and returns
        a GetOrganizationAdminResponse message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookUpOrganizationAdmin(self, request, context):
        """LookUpOrganizationAdmin method receives a LookUpOrganizationAdminRequest message and
        returns a LookUpOrganizationAdminResponse
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserSubscriptionAdmin(self, request, context):
        """GetUserSubscriptionAdmin
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationSubscriptionAdmin(self, request, context):
        """GetOrganizationSubscriptionAdmin
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MgmtPrivateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListUsersAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsersAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminResponse.SerializeToString,
            ),
            'GetUserAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminResponse.SerializeToString,
            ),
            'LookUpUserAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.LookUpUserAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminResponse.SerializeToString,
            ),
            'ListOrganizationsAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationsAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminResponse.SerializeToString,
            ),
            'GetOrganizationAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminResponse.SerializeToString,
            ),
            'LookUpOrganizationAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.LookUpOrganizationAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminResponse.SerializeToString,
            ),
            'GetUserSubscriptionAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserSubscriptionAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminResponse.SerializeToString,
            ),
            'GetOrganizationSubscriptionAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationSubscriptionAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'core.mgmt.v1beta.MgmtPrivateService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MgmtPrivateService(object):
    """Mgmt service responds to internal access
    """

    @staticmethod
    def ListUsersAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/ListUsersAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/GetUserAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LookUpUserAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/LookUpUserAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationsAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/ListOrganizationsAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/GetOrganizationAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LookUpOrganizationAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/LookUpOrganizationAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserSubscriptionAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/GetUserSubscriptionAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationSubscriptionAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/GetOrganizationSubscriptionAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# generated by datamodel-codegen:
#   filename:  instill_task_detection_input.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Input:
    image_base64: str
    model_name: str



# generated by datamodel-codegen:
#   filename:  pinecone_task_query_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict, List, Optional


@dataclass
class Input:
    vector: List[float]
    top_k: int
    id: Optional[str] = None
    namespace: Optional[str] = None
    filter: Optional[Dict[str, Any]] = None
    min_score: Optional[float] = None
    include_metadata: Optional[bool] = False
    include_values: Optional[bool] = False



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import core.mgmt.v1beta.mgmt_pb2
import grpc
import grpc.aio
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class MgmtPrivateServiceStub:
    """Mgmt service responds to internal access"""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ListUsersAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListUsersAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.ListUsersAdminResponse,
    ]
    """ListUsersAdmin method receives a ListUsersAdminRequest message and returns
    a ListUsersAdminResponse message.
    """
    GetUserAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserAdminResponse,
    ]
    """GetUserAdmin method receives a GetUserAdminRequest message and returns
    a GetUserAdminResponse message.
    """
    LookUpUserAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminResponse,
    ]
    """LookUpUserAdmin method receives a LookUpUserAdminRequest message and
    returns a LookUpUserAdminResponse
    """
    ListOrganizationsAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminResponse,
    ]
    """ListOrganizationsAdmin method receives a ListOrganizationsAdminRequest message and returns
    a ListOrganizationsAdminResponse message.
    """
    GetOrganizationAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminResponse,
    ]
    """GetOrganizationAdmin method receives a GetOrganizationAdminRequest message and returns
    a GetOrganizationAdminResponse message.
    """
    LookUpOrganizationAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminResponse,
    ]
    """LookUpOrganizationAdmin method receives a LookUpOrganizationAdminRequest message and
    returns a LookUpOrganizationAdminResponse
    """
    GetUserSubscriptionAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminResponse,
    ]
    """GetUserSubscriptionAdmin"""
    GetOrganizationSubscriptionAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminResponse,
    ]
    """GetOrganizationSubscriptionAdmin"""

class MgmtPrivateServiceAsyncStub:
    """Mgmt service responds to internal access"""

    ListUsersAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListUsersAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.ListUsersAdminResponse,
    ]
    """ListUsersAdmin method receives a ListUsersAdminRequest message and returns
    a ListUsersAdminResponse message.
    """
    GetUserAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserAdminResponse,
    ]
    """GetUserAdmin method receives a GetUserAdminRequest message and returns
    a GetUserAdminResponse message.
    """
    LookUpUserAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminResponse,
    ]
    """LookUpUserAdmin method receives a LookUpUserAdminRequest message and
    returns a LookUpUserAdminResponse
    """
    ListOrganizationsAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminResponse,
    ]
    """ListOrganizationsAdmin method receives a ListOrganizationsAdminRequest message and returns
    a ListOrganizationsAdminResponse message.
    """
    GetOrganizationAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminResponse,
    ]
    """GetOrganizationAdmin method receives a GetOrganizationAdminRequest message and returns
    a GetOrganizationAdminResponse message.
    """
    LookUpOrganizationAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminResponse,
    ]
    """LookUpOrganizationAdmin method receives a LookUpOrganizationAdminRequest message and
    returns a LookUpOrganizationAdminResponse
    """
    GetUserSubscriptionAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminResponse,
    ]
    """GetUserSubscriptionAdmin"""
    GetOrganizationSubscriptionAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminResponse,
    ]
    """GetOrganizationSubscriptionAdmin"""

class MgmtPrivateServiceServicer(metaclass=abc.ABCMeta):
    """Mgmt service responds to internal access"""

    @abc.abstractmethod
    def ListUsersAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.ListUsersAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.ListUsersAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.ListUsersAdminResponse]]:
        """ListUsersAdmin method receives a ListUsersAdminRequest message and returns
        a ListUsersAdminResponse message.
        """
    @abc.abstractmethod
    def GetUserAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetUserAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetUserAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetUserAdminResponse]]:
        """GetUserAdmin method receives a GetUserAdminRequest message and returns
        a GetUserAdminResponse message.
        """
    @abc.abstractmethod
    def LookUpUserAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminResponse]]:
        """LookUpUserAdmin method receives a LookUpUserAdminRequest message and
        returns a LookUpUserAdminResponse
        """
    @abc.abstractmethod
    def ListOrganizationsAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminResponse]]:
        """ListOrganizationsAdmin method receives a ListOrganizationsAdminRequest message and returns
        a ListOrganizationsAdminResponse message.
        """
    @abc.abstractmethod
    def GetOrganizationAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminResponse]]:
        """GetOrganizationAdmin method receives a GetOrganizationAdminRequest message and returns
        a GetOrganizationAdminResponse message.
        """
    @abc.abstractmethod
    def LookUpOrganizationAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminResponse]]:
        """LookUpOrganizationAdmin method receives a LookUpOrganizationAdminRequest message and
        returns a LookUpOrganizationAdminResponse
        """
    @abc.abstractmethod
    def GetUserSubscriptionAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminResponse]]:
        """GetUserSubscriptionAdmin"""
    @abc.abstractmethod
    def GetOrganizationSubscriptionAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminResponse]]:
        """GetOrganizationSubscriptionAdmin"""

def add_MgmtPrivateServiceServicer_to_server(servicer: MgmtPrivateServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
